From 6135d79bcd44a576df488c231f5dd1697ccb762c Mon Sep 17 00:00:00 2001
From: jurgenhaas <juergen.haas@lakedrops.com>
Date: Tue, 25 Jun 2024 18:32:09 +0200
Subject: [PATCH] composer/plugin/drupal-development-environment#20

---
 src/Handler.php                  | 6 +++++-
 templates/tests/phpcs.files      | 1 +
 templates/tests/phpunit.xml.dist | 1 +
 3 files changed, 7 insertions(+), 1 deletion(-)

diff --git a/templates/tests/phpcs.files b/templates/tests/phpcs.files
index 1efc94e..1dbabc6 100644
--- a/templates/tests/phpcs.files
+++ b/templates/tests/phpcs.files
@@ -1,3 +1,4 @@
 /var/www/html/web/modules/custom/
 /var/www/html/web/profiles/custom/
+/var/www/html/web/recipes/custom/
 /var/www/html/web/themes/custom/
diff --git a/templates/tests/phpunit.xml.dist b/templates/tests/phpunit.xml.dist
index ee2050f..097d681 100644
--- a/templates/tests/phpunit.xml.dist
+++ b/templates/tests/phpunit.xml.dist
@@ -61,6 +61,7 @@
     <include>
       <directory>../web/modules/custom</directory>
       <directory>../web/profiles/custom</directory>
+      <directory>../web/recipes/custom</directory>
       <directory>../web/themes/custom</directory>
 {% for path in coverage %}
       <directory>{{ path }}</directory>
diff --git a/src/Handler.php b/src/Handler.php
index ae127cc..7b655d9 100644
--- a/src/Handler.php
+++ b/src/Handler.php
@@ -70,14 +70,18 @@ class Handler extends BaseHandler {
     // Directory where this plugin is being installed.
     $pluginRoot = $installationManager->getInstallPath($this->getPackage('lakedrops/drupal-development-environment'));
 
     // Create contrib/custom dirs for modules, profiles and themes.
     foreach ([
       $webRoot . '/modules',
       $webRoot . '/profiles',
+      $webRoot . '/recipes',
       $webRoot . '/themes',
     ] as $dir) {
       foreach (['contrib', 'custom'] as $subdir) {
         $path = $dir . '/' . $subdir;
+        if ($subdir === 'contrib') {
+          $this->gitIgnore($path);
+        }
         if (!$fs->exists($path)) {
           $fs->mkdir($path, 0775);
         }
@@ -70,14 +70,18 @@ class Handler extends BaseHandler {
     $pluginRoot = $installationManager->getInstallPath($this->getPackage('lakedrops/drupal-development-environment'));
 
-    // Create contrib/custom dirs for modules, profiles and themes.
+    // Create contrib/custom dirs for modules, profiles, recipes and themes.
     foreach ([
       $webRoot . '/modules',
-- 
GitLab